<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ws="http://www.ebenoit.info/data"
	xmlns:wsf="http://www.ebenoit.info/ext">


	<!-- *********************************************************************************************** -->
	<!-- * MENU GENERATOR                                                                              * -->
	<!-- *********************************************************************************************** -->


	<!-- Generate the menu's box
	   -
	   - This template generates a side box to be used by the menu and calls the menu generator
	   - itself.
	  -->
	<xsl:template name="generate-menu-box">
		<xsl:call-template name="side-box-template">
			<xsl:with-param name="id">menu-box</xsl:with-param>
			<xsl:with-param name="title">
				<xsl:call-template name="get-i18n-string">
					<xsl:with-param name="id">menu</xsl:with-param>
				</xsl:call-template>
			</xsl:with-param>
			<xsl:with-param name="contents">
				<xsl:call-template name="generate-menu" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>


	<!-- Generate the menu
	   -
	   - This template generates the contents of the menu box.
	  -->
	<xsl:template name="generate-menu">
		<xsl:variable name="menu-structure" select="wsf:generate-menu( string( $lang ) , string( $page ) )" />

		<xsl:choose>
			<xsl:when test="$menu-structure/ws:menu-item">
				<xsl:call-template name="menu-template">
					<xsl:with-param name="top-level" select="true()" />
					<xsl:with-param name="contents">
						<xsl:for-each select="$menu-structure/ws:menu-item">
							<xsl:call-template name="make-menu-item" />
						</xsl:for-each>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<div class="line-content">
					<xsl:value-of select="wsf:get-i18n-string( 'empty-menu' , string( $lang ) )" />
				</div>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>


	<!-- Generate a menu item
	   -
	   - This template generates the code for a menu item as well as its
	   - sub-menu, if there is one.
	  -->
	<xsl:template name="make-menu-item">
		<xsl:call-template name="menu-item-template">
			<xsl:with-param name="open" select="@open = '1'" />
			<xsl:with-param name="contents" select="ws:content/node()" />
			<xsl:with-param name="sub-menu">
				<xsl:if test="ws:sub-menu">
					<xsl:call-template name="menu-template">
						<xsl:with-param name="contents">
							<xsl:for-each select="ws:sub-menu/ws:menu-item">
								<xsl:call-template name="make-menu-item" />
							</xsl:for-each>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

</xsl:stylesheet>

